[![Documentation Status](https://readthedocs.org/projects/doubledate/badge/?version=latest)](https://doubledate.readthedocs.io/en/latest/?badge=latest)

## Documentation
Documentation is hosted on [read the docs](https://doubledate.readthedocs.io/en/latest/)
